Function weather_cli::api_usage::search_city
source · pub async fn search_city(query: &String) -> Result<()>Expand description
Retrieve cities with the search query and saves the selected city.
pub async fn search_city(query: &String) -> Result<()>Retrieve cities with the search query and saves the selected city.