Function weather_cli::get_json_file
source · pub fn get_json_file(name: &str) -> Result<File>Expand description
Formats the given file name with the executable directory.
pub fn get_json_file(name: &str) -> Result<File>Formats the given file name with the executable directory.