Function weather_cli::read_json_file
source · pub fn read_json_file<T: DeserializeOwned>(json_name: &str) -> Result<T>Expand description
Reads the given json file and returns the string.
pub fn read_json_file<T: DeserializeOwned>(json_name: &str) -> Result<T>Reads the given json file and returns the string.