Function weather_cli::read_json_file
source · pub fn read_json_file(json_name: &str) -> Result<String>Expand description
Reads the given json file and returns the string.
pub fn read_json_file(json_name: &str) -> Result<String>Reads the given json file and returns the string.